[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible armhf: add 3 more build jobs

Holger Levsen holger at moszumanska.debian.org
Wed Nov 11 00:45:16 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit ce694911a70e93a548de0d8135d27c6f2dd75cf5
Author: Holger Levsen <holger at layer-acht.org>
Date:   Wed Nov 11 01:00:18 2015 +0100

    reproducible armhf: add 3 more build jobs
---
 README                               |  4 ++--
 bin/reproducible_html_live_status.py |  4 ++--
 job-cfg/reproducible.yaml            | 30 ++++++++++++++++++++++++++++++
 3 files changed, 34 insertions(+), 4 deletions(-)

diff --git a/README b/README
index 9e4ffef..9db633c 100644
--- a/README
+++ b/README
@@ -137,10 +137,10 @@ Installation tests inside chroot environments.
 
 * The (current) purpose of https://reproducible.debian.net is to show the prospects of reproducible builds for Debian. IOW: this is research, showing what could (and should) be done... check https://wiki.debian.org/ReproducibleBuilds for the real status of the project!
 
-* Currently, three suites are tested on amd64: 'testing', 'unstable' and 'experimental'. The tests are done using 'pbuilder' using link:https://wiki.debian.org/ReproducibleBuilds/ExperimentalToolchain[our toolchain] through concurrent builder jobs, 16 for 'amd64' and 10 for 'armhf', which are each constantly testing packages and saving the results of these tests.
+* Currently, three suites are tested on amd64: 'testing', 'unstable' and 'experimental'. The tests are done using 'pbuilder' using link:https://wiki.debian.org/ReproducibleBuilds/ExperimentalToolchain[our toolchain] through concurrent builder jobs, 16 for 'amd64' and 13 for 'armhf', which are each constantly testing packages and saving the results of these tests.
 
 ** These builds on remote nodes run on very different hardware: for 'amd64' we are now using four virtual machines, profitbricks-build(1+2+5+6)-amd64, which have 16 or 17 cores and 48gb ram each and are sponsored by link:https://jenkins.debian.net/userContent/thanks.html[Profitbricks].
-** To test 'armhf' we are using four small boards donated by vagrant at d.o: three quad cores (wbq0, cbxi4pro0 and odxu4) with 2gb ram and two dual cores (bpi0 and hb0) with 1gb ram, each. We would love to have more or more powerful ARM hardware in the future, if you can help, please talk to us!
+** To test 'armhf' we are using four small boards donated by vagrant at d.o: three quad cores (wbq0, cbxi4pro0 and odxu4) with 2gb ram and three dual cores (bpi0, hb0 and wbd0) with 1gb ram, each. We would love to have more or more powerful ARM hardware in the future, if you can help, please talk to us!
 
 * Packages to be build are scheduled in the SQLite database via a scheduler job, which runs every hour and if the queue is below a certain threshold schedules four types of packages:
 ** new untested packages (either uploaded to 'unstable' or 'experimental' or migrated to 'testing'),
diff --git a/job-cfg/reproducible.yaml b/job-cfg/reproducible.yaml
index 0873dca..35d659f 100644
--- a/job-cfg/reproducible.yaml
+++ b/job-cfg/reproducible.yaml
@@ -714,6 +714,18 @@
     name: '{name}_builder_armhf_10'
 
 - job-template:
+    defaults: reproducible_builder
+    name: '{name}_builder_armhf_11'
+
+- job-template:
+    defaults: reproducible_builder
+    name: '{name}_builder_armhf_12'
+
+- job-template:
+    defaults: reproducible_builder
+    name: '{name}_builder_armhf_13'
+
+- job-template:
     defaults: reproducible_other_projects_trigger
     name: '{name}_coreboot'
 
@@ -1416,6 +1428,24 @@
             my_shell: '/srv/jenkins/bin/reproducible_build.sh odxu4-armhf-rb:2229 hb0-armhf-rb:2224'
             my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
             my_node: ''
+        - '{name}_builder_armhf_11':
+            my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
+            my_timed: '* * * * *'
+            my_shell: '/srv/jenkins/bin/reproducible_build.sh odxu4-armhf-rb:2229 wbd0-armhf-rb:2223'
+            my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
+            my_node: ''
+        - '{name}_builder_armhf_12':
+            my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
+            my_timed: '* * * * *'
+            my_shell: '/srv/jenkins/bin/reproducible_build.sh wbd0-armhf-rb:2223 odxu4-armhf-rb:2229'
+            my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
+            my_node: ''
+        - '{name}_builder_armhf_13':
+            my_description: 'Try to reproducibly build a scheduled package. This is one of several builder jobs.'
+            my_timed: '* * * * *'
+            my_shell: '/srv/jenkins/bin/reproducible_build.sh cbxi4pro0-armhf-rb:2226 wbd0-armhf-rb:2223'
+            my_recipients: 'qa-jenkins-scm at lists.alioth.debian.org'
+            my_node: ''
         - '{name}_coreboot':
             my_description: 'Rebuild all coreboot ROMs twice (with variations) and investigate regarding reproducibility.'
             my_timed: '42 23 * * 1'

diff --git a/bin/reproducible_html_live_status.py b/bin/reproducible_html_live_status.py
index 6f84677..a7c3fe2 100755
--- a/bin/reproducible_html_live_status.py
+++ b/bin/reproducible_html_live_status.py
@@ -66,8 +66,8 @@ def generate_live_status_table(arch):
     counter = 0
     for row in rows:
         counter += 1
-        # the numbers 33 and 11 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
-        if ( arch == 'amd64' and counter == 33 ) or ( arch == 'armhf' and counter == 9 ):
+        # the numbers 33 and 14 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
+        if ( arch == 'amd64' and counter == 33 ) or ( arch == 'armhf' and counter == 14 ):
              html += '<tr><td colspan="10">There are more builds marked as currently building in the database than there are ' + arch + ' build jobs. This does not compute, please investigate and fix the cause.</td></tr>'
         suite = row[1]
         arch = row[2]
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list